==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/OnPopupEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnPopupEventArgsDescription } from "./OnPopupEventArgsDescription";
/**
 * @hidden
 */
var OnPopupEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnPopupEventArgsDescriptionMetadata, _super);
    function OnPopupEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnPopupEventArgsDescriptionMetadata.b = function (a) {
        if (OnPopupEventArgsDescriptionMetadata.a == null) {
            OnPopupEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnPopupEventArgsDescriptionMetadata.c(OnPopupEventArgsDescriptionMetadata.a);
        }
        if (a.g(OnPopupEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(OnPopupEventArgsDescriptionMetadata.a);
    };
    OnPopupEventArgsDescriptionMetadata.c = function (a) {
    };
    OnPopupEventArgsDescriptionMetadata.d = function (a) {
        OnPopupEventArgsDescriptionMetadata.b(a);
        a.u("OnPopupEventArgs", function () { return new OnPopupEventArgsDescription(); });
        a.t("OnPopupEventArgs", OnPopupEventArgsDescriptionMetadata.a);
    };
    OnPopupEventArgsDescriptionMetadata.$t = markType(OnPopupEventArgsDescriptionMetadata, 'OnPopupEventArgsDescriptionMetadata');
    OnPopupEventArgsDescriptionMetadata.a = null;
    return OnPopupEventArgsDescriptionMetadata;
}(Base));
export { OnPopupEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/OnPopupEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnPopupEventArgsDescription } from "./OnPopupEventArgsDescription";
/**
 * @hidden
 */
var OnPopupEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnPopupEventArgsDescriptionMetadata, _super);
    function OnPopupEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnPopupEventArgsDescriptionMetadata.b = function (a) {
        if (OnPopupEventArgsDescriptionMetadata.a == null) {
            OnPopupEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnPopupEventArgsDescriptionMetadata.c(OnPopupEventArgsDescriptionMetadata.a);
        }
        if (a.j(OnPopupEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(OnPopupEventArgsDescriptionMetadata.a);
    };
    OnPopupEventArgsDescriptionMetadata.c = function (a) {
    };
    OnPopupEventArgsDescriptionMetadata.d = function (a) {
        OnPopupEventArgsDescriptionMetadata.b(a);
        a.aa("OnPopupEventArgs", function () { return new OnPopupEventArgsDescription(); });
        a.z("OnPopupEventArgs", OnPopupEventArgsDescriptionMetadata.a);
    };
    OnPopupEventArgsDescriptionMetadata.$t = markType(OnPopupEventArgsDescriptionMetadata, 'OnPopupEventArgsDescriptionMetadata');
    OnPopupEventArgsDescriptionMetadata.a = null;
    return OnPopupEventArgsDescriptionMetadata;
}(Base));
export { OnPopupEventArgsDescriptionMetadata };
